package com.cesanelli.lajusta;

import android.content.SharedPreferences;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.TextView;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import androidx.appcompat.widget.Toolbar;
import androidx.drawerlayout.widget.DrawerLayout;
import androidx.lifecycle.ViewModelProvider;
import androidx.navigation.NavController;
import androidx.navigation.Navigation;
import androidx.navigation.ui.AppBarConfiguration;
import androidx.navigation.ui.NavigationUI;

import com.cesanelli.lajusta.io.ApiAdapter;
import com.cesanelli.lajusta.io.models.Token;
import com.cesanelli.lajusta.io.models.User;
import com.cesanelli.lajusta.ui.viewmodel.CartViewModel;
import com.cesanelli.lajusta.ui.viewmodel.UserViewModel;
import com.google.android.material.navigation.NavigationView;

import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;

public class MainActivity extends AppCompatActivity {

    private AppBarConfiguration mAppBarConfiguration;
    private SharedPreferences sharedpreferences;
    private NavigationView navigationView;
    private NavController navController;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        sharedpreferences = PreferenceManager.getDefaultSharedPreferences(this);

        setContentView(R.layout.activity_main);
        Toolbar toolbar = findViewById(R.id.toolbar);
        setSupportActionBar(toolbar);
        DrawerLayout drawer = findViewById(R.id.drawer_layout);
        // Passing each menu ID as a set of Ids because each
        // menu should be considered as top level destinations.
        mAppBarConfiguration = new AppBarConfiguration.Builder(
                R.id.nav_quienes_somos, R.id.nav_news, R.id.nav_producers, R.id.nav_products, R.id.nav_cart, R.id.nav_login)
                .setDrawerLayout(drawer)
                .build();

        UserViewModel userViewModel = new ViewModelProvider(this).get(UserViewModel.class);
        userViewModel.getToken().observe(this, token -> {
            String jwt = sharedpreferences.getString("JWT", "");
            navigationView.getMenu().findItem(R.id.nav_login).setVisible(jwt == "");
            navigationView.getMenu().findItem(R.id.nav_logout).setVisible(jwt != "");
            TextView email = (TextView) navigationView.getHeaderView(0).findViewById(R.id.text_email);
            email.setText(jwt == "" ? "" : token.getUser().getFirstName() + " " + token.getUser().getLastName());
        });
        navigationView = findViewById(R.id.nav_view);
        navigationView.getMenu().findItem(R.id.nav_logout).setOnMenuItemClickListener(new MenuItem.OnMenuItemClickListener() {
            @Override
            public boolean onMenuItemClick(MenuItem item) {
                sharedpreferences.edit().putString("JWT", "").apply();
                sharedpreferences.edit().putString("UserID", "").apply();
                userViewModel.setToken(new Token());
                Toast.makeText(getApplicationContext(), "Logout realizado correctamente.", Toast.LENGTH_LONG).show();
                return true;
            }
        });

        navController = Navigation.findNavController(this, R.id.nav_host_fragment);
        NavigationUI.setupActionBarWithNavController(this, navController, mAppBarConfiguration);
        NavigationUI.setupWithNavController(navigationView, navController);
        checkToken();
    }

    private void checkToken() {
        String jwt = sharedpreferences.getString("JWT", "");
        String userId = sharedpreferences.getString("UserID", "");
        UserViewModel userViewModel = new ViewModelProvider(this).get(UserViewModel.class);
        if (jwt != "" && userId != "") {
            Call<User> call = ApiAdapter.getApiService().getUser(Integer.parseInt(userId), "Bearer " + jwt);
            call.enqueue(new Callback<User>() {
                @Override
                public void onResponse(Call<User> call, Response<User> response) {
                    Token token = new Token();
                    try {
                        if (response.isSuccessful()) {

                            token.setValue(jwt);
                            token.setUser(response.body());
                        } else {
                            sharedpreferences.edit().putString("JWT", "").apply();
                            sharedpreferences.edit().putString("UserID", "").apply();
                        }
                    } catch (Exception ex) {
                        sharedpreferences.edit().putString("JWT", "").apply();
                        sharedpreferences.edit().putString("UserID", "").apply();
                    } finally {
                        userViewModel.setToken(token);
                    }
                }

                @Override
                public void onFailure(Call<User> call, Throwable t) {
                    sharedpreferences.edit().putString("JWT", "").apply();
                }
            });
        } else {
            userViewModel.setToken(new Token());
        }
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(@NonNull MenuItem item) {
        return NavigationUI.onNavDestinationSelected(item, navController) || super.onOptionsItemSelected(item);
    }

    @Override
    public boolean onSupportNavigateUp() {
        return NavigationUI.navigateUp(navController, mAppBarConfiguration)
                || super.onSupportNavigateUp();
    }
}