package com.cesanelli.lajusta.ui;

import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.fragment.app.Fragment;
import androidx.lifecycle.ViewModelProvider;
import androidx.navigation.Navigation;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.cesanelli.lajusta.R;
import com.cesanelli.lajusta.databinding.FragmentCartListBinding;
import com.cesanelli.lajusta.io.models.CartItem;
import com.cesanelli.lajusta.ui.viewmodel.CartViewModel;

public class CartFragment extends Fragment implements CartRecyclerViewAdapter.OnCartListener {
    private FragmentCartListBinding fragmentCartListBinding;
    private CartViewModel cartViewModel;

    public CartFragment() {
        // Required empty public constructor
    }

    public static CartFragment newInstance(String param1, String param2) {
        CartFragment fragment = new CartFragment();
        return fragment;
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        LayoutInflater layoutInflater = LayoutInflater.from(getContext());
        fragmentCartListBinding = FragmentCartListBinding.inflate(layoutInflater, container, false);
        return fragmentCartListBinding.getRoot();
    }

    @Override
    public void onViewCreated(@NonNull View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);
        Button btnComprar = view.findViewById(R.id.btnBuy);

        cartViewModel = new ViewModelProvider(getActivity()).get(CartViewModel.class);
        cartViewModel.getCart().observe(getActivity(), cart -> {
            if (cart != null) {
                RecyclerView recyclerView = (RecyclerView) view.findViewById(R.id.cartList);
                recyclerView.setLayoutManager(new LinearLayoutManager(getContext()));
                recyclerView.setAdapter(new CartRecyclerViewAdapter(cart, this));
                fragmentCartListBinding.setCart(cart);
                btnComprar.setEnabled(cart.getTotal() > 0);
            }
        });

        btnComprar.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Navigation.findNavController(v).navigate(R.id.nav_purchase);
            }
        });
    }

    @Override
    public void onProductRemove(CartItem cartItem) {
        cartViewModel.deleteProduct(cartItem.getProduct().getId());
        Toast.makeText(getContext(), "Se eliminó " + cartItem.getProduct().getTitle() + " al carrito.", Toast.LENGTH_SHORT).show();
    }

    @Override
    public void onAddQuantity(CartItem cartItem) {
        if (cartItem.getQuantity() < cartItem.getProduct().getStock()) {
            cartViewModel.addQuantity(cartItem.getProduct().getId());
        } else {
            Toast.makeText(getContext(), "No hay stock suficiente.", Toast.LENGTH_LONG).show();
        }
    }

    @Override
    public void onRemoveQuantity(CartItem cartItem) {
        cartViewModel.removeQuantity(cartItem.getProduct().getId());
    }
}