package com.cesanelli.lajusta.ui;

import android.view.LayoutInflater;
import android.view.ViewGroup;

import androidx.recyclerview.widget.RecyclerView;

import com.cesanelli.lajusta.databinding.FragmentCartBinding;
import com.cesanelli.lajusta.io.models.Cart;
import com.cesanelli.lajusta.io.models.CartItem;


public class CartRecyclerViewAdapter extends RecyclerView.Adapter<CartRecyclerViewAdapter.ViewHolder> {

    private final Cart cart;
    private OnCartListener onCartListener;


    public CartRecyclerViewAdapter(Cart cart, OnCartListener onCartListener) {
        this.cart = cart;
        this.onCartListener = onCartListener;
    }

    @Override
    public ViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        LayoutInflater layoutInflater = LayoutInflater.from(parent.getContext());
        FragmentCartBinding fragmentCartBinding = FragmentCartBinding.inflate(layoutInflater, parent, false);
        return new CartRecyclerViewAdapter.ViewHolder(fragmentCartBinding);
    }

    @Override
    public void onBindViewHolder(final ViewHolder holder, int position) {
        CartItem cartItem = cart.getCartProducts().get(position);
        holder.fragmentCartBinding.setCartItem(cartItem);
        holder.fragmentCartBinding.setOnCartListener(onCartListener);;
    }

    @Override
    public int getItemCount() {
        return cart.getCartProducts().size();
    }

    public interface OnCartListener {
        void onProductRemove(CartItem cartItem);
        void onAddQuantity(CartItem cartItem);
        void onRemoveQuantity(CartItem cartItem);
    }

    public class ViewHolder extends RecyclerView.ViewHolder {
        public FragmentCartBinding fragmentCartBinding;
        public ViewHolder(FragmentCartBinding binding) {
            super(binding.getRoot());
            this.fragmentCartBinding = binding;
        }
    }
}