package com.cesanelli.lajusta.ui;

import android.content.SharedPreferences;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.fragment.app.Fragment;
import androidx.lifecycle.ViewModelProvider;
import androidx.navigation.Navigation;

import com.cesanelli.lajusta.R;
import com.cesanelli.lajusta.io.ApiAdapter;
import com.cesanelli.lajusta.io.models.Signup;
import com.cesanelli.lajusta.io.models.Token;
import com.cesanelli.lajusta.io.models.TokenBody;
import com.cesanelli.lajusta.ui.viewmodel.UserViewModel;

import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;

public class LoginFragment extends Fragment {
    private TextView login_user;
    private TextView login_password;

    public LoginFragment() {
        // Required empty public constructor
    }

    public static LoginFragment newInstance() {
        LoginFragment fragment = new LoginFragment();
        return fragment;
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        // Inflate the layout for this fragment
        return inflater.inflate(R.layout.fragment_login, container, false);
    }

    @Override
    public void onViewCreated(@NonNull View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);
        Button btnLogin = view.findViewById(R.id.btn_login);
        Button btnRegistrar = view.findViewById(R.id.btn_register);
        login_user = (TextView) view.findViewById(R.id.login_user);
        login_password = (TextView) view.findViewById(R.id.login_password);

        btnLogin.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {

                SharedPreferences sharedpreferences = PreferenceManager.getDefaultSharedPreferences(getContext());
                Call<Token> call = ApiAdapter.getApiService().login(new TokenBody(login_user.getText().toString().trim(), Signup.md5(login_password.getText().toString().trim())));

                call.enqueue(new Callback<Token>() {

                    @Override
                    public void onResponse(Call<Token> call, Response<Token> response) {
                        try {
                            if (response.isSuccessful()) {
                                Token token = response.body();
                                sharedpreferences.edit().putString("JWT", token.getValue()).apply();
                                sharedpreferences.edit().putString("UserID", Integer.toString(token.getUser().getId())).apply();
                                UserViewModel userViewModel = new ViewModelProvider(getActivity()).get(UserViewModel.class);
                                userViewModel.setToken(token);
                                Toast.makeText(getContext(), "¡Bienvenido " + token.getUser().getFirstName() + "!", Toast.LENGTH_LONG).show();
                                Navigation.findNavController(v).navigate(R.id.nav_products);
                            } else {
                                Toast.makeText(getContext(), "Usuario o password incorrectos.", Toast.LENGTH_LONG).show();
                            }
                        } catch (Exception ex) {
                            System.out.println(ex.getMessage());
                            Toast.makeText(getContext(), "Error en login. Por favor intente nuevamente.", Toast.LENGTH_LONG).show();
                        }
                    }

                    @Override
                    public void onFailure(Call<Token> call, Throwable t) {
                        System.out.println(t.getMessage());
                        Toast.makeText(getContext(), "Error en login. Por favor intente nuevamente.", Toast.LENGTH_LONG).show();
                    }
                });
            }
        });

        btnRegistrar.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Navigation.findNavController(v).navigate(R.id.nav_register);
            }
        });
    }
}