package com.cesanelli.lajusta.ui;

import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.PorterDuff;
import android.util.Base64;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import androidx.recyclerview.widget.RecyclerView;

import com.cesanelli.lajusta.R;
import com.cesanelli.lajusta.io.models.News;
import com.cesanelli.lajusta.io.models.NewsItem;

import java.util.List;

/**
 * {@link RecyclerView.Adapter} that can display a {@link News}.
 * TODO: Replace the implementation with code for your data type.
 */
public class NewsRecyclerViewAdapter extends RecyclerView.Adapter<NewsRecyclerViewAdapter.ViewHolder> {

    private final List<NewsItem> news;

    public NewsRecyclerViewAdapter(List<NewsItem> news) {
        this.news = news;
    }

    @Override
    public ViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        View view = LayoutInflater.from(parent.getContext())
                .inflate(R.layout.fragment_news, parent, false);
        return new ViewHolder(view);
    }

    @Override
    public void onBindViewHolder(final ViewHolder holder, int position) {
        holder.news = news.get(position);
        if (holder.news.getImage() != null) {
            String cleanImage = holder.news.getImage().getValue().replace("data:image/png;base64,", "").replace("data:image/jpeg;base64,", "");
            byte[] decodedString = Base64.decode(cleanImage, Base64.DEFAULT);
            Bitmap decodedByte = BitmapFactory.decodeByteArray(decodedString, 0, decodedString.length);
            holder.news_image.setImageBitmap(decodedByte);
        }else{
            holder.news_image.setImageResource(R.drawable.ic_baseline_person_24);
            holder.news_image.setColorFilter( 0xffcccccc, PorterDuff.Mode.MULTIPLY );
        }
        holder.news_title.setText(holder.news.getTitle());
        holder.news_subtitle.setText(holder.news.getSubtitle());
        holder.news_text.setText(holder.news.getText());
    }

    @Override
    public int getItemCount() {
        return news.size();
    }

    public class ViewHolder extends RecyclerView.ViewHolder {
        public final View mView;
        public final ImageView news_image;
        public final TextView news_title;
        public final TextView news_subtitle;
        public final TextView news_text;
        public NewsItem news;

        public ViewHolder(View view) {
            super(view);
            mView = view;
            news_image = (ImageView) view.findViewById(R.id.news_image);
            news_title = (TextView) view.findViewById(R.id.news_title);
            news_subtitle = (TextView) view.findViewById(R.id.news_subtitle);
            news_text = (TextView) view.findViewById(R.id.news_text);
        }

        @Override
        public String toString() {
            return super.toString() + " '" + news_title.getText() + "'";
        }
    }
}