package com.cesanelli.lajusta.ui;

import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.PorterDuff;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.util.Base64;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.fragment.app.Fragment;
import androidx.lifecycle.ViewModelProvider;

import com.cesanelli.lajusta.R;
import com.cesanelli.lajusta.ui.viewmodel.ProducerViewModel;

public class ProducerFragment extends Fragment {
    private ProducerViewModel viewModel;
    private TextView producer_name;
    private ImageView producer_image;
    private TextView producer_email;
    private TextView producer_description;

    public ProducerFragment() {
        // Required empty public constructor
    }

    public static ProducerFragment newInstance() {
        ProducerFragment fragment = new ProducerFragment();
        return fragment;
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        // Inflate the layout for this fragment
        return inflater.inflate(R.layout.fragment_producer, container, false);
    }

    @Override
    public void onViewCreated(@NonNull View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);
        viewModel = new ViewModelProvider(getActivity()).get(ProducerViewModel.class);
        producer_name = (TextView) view.findViewById(R.id.producer_name);
        producer_image = (ImageView) view.findViewById(R.id.producer_image);
        producer_description = (TextView) view.findViewById(R.id.producer_description);
        producer_email = (TextView) view.findViewById(R.id.producer_email);
        viewModel.getProducer().observe(getViewLifecycleOwner(), producer -> {
            producer_name.setText(producer.getName());
            producer_email.setText(producer.getEmail());
            if (producer.getImages().length > 0) {
                String cleanImage = producer.getImages()[0].getValue().replace("data:image/png;base64,", "").replace("data:image/jpeg;base64,", "");
                byte[] decodedString = Base64.decode(cleanImage, Base64.DEFAULT);
                Bitmap decodedByte = BitmapFactory.decodeByteArray(decodedString, 0, decodedString.length);
                producer_image.setImageBitmap(decodedByte);
            } else {
                producer_image.setImageResource(R.drawable.ic_baseline_person_24);
                producer_image.setColorFilter( 0xffcccccc, PorterDuff.Mode.MULTIPLY );
            }
            producer_description.setText(producer.getDescription());
        });
    }
}