package com.cesanelli.lajusta.ui;

import android.content.Context;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.fragment.app.Fragment;
import androidx.lifecycle.ViewModelProvider;
import androidx.navigation.Navigation;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.cesanelli.lajusta.R;
import com.cesanelli.lajusta.io.ApiAdapter;
import com.cesanelli.lajusta.io.models.Producer;
import com.cesanelli.lajusta.ui.viewmodel.ProducerListViewModel;
import com.cesanelli.lajusta.ui.viewmodel.ProducerViewModel;

import java.util.ArrayList;

import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;

/**
 * A fragment representing a list of Items.
 */
public class ProducersFragment extends Fragment implements ProducersRecyclerViewAdapter.OnProducerListener {
    private ProducerViewModel producerViewModel;
    private ProducerListViewModel producerListViewModel;

    public ProducersFragment() {
    }

    public static ProducersFragment newInstance() {
        ProducersFragment fragment = new ProducersFragment();
        return fragment;
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        return inflater.inflate(R.layout.fragment_producers_list, container, false);
    }

    @Override
    public void onViewCreated(@NonNull View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);
        producerViewModel = new ViewModelProvider(getActivity()).get(ProducerViewModel.class);
        producerListViewModel = new ViewModelProvider(getActivity()).get(ProducerListViewModel.class);
        producerListViewModel.getProducerList().observe(getViewLifecycleOwner(), list ->{
            if (list != null) {
                RecyclerView recyclerView = (RecyclerView) view;
                recyclerView.setLayoutManager(new LinearLayoutManager(getContext()));
                recyclerView.setAdapter(new ProducersRecyclerViewAdapter((ArrayList<Producer>) list, this));
            }
        });
    }

    @Override
    public void onProducerClick(Producer producer) {
        producerViewModel.setProducer(producer);
        Navigation.findNavController(getView()).navigate(R.id.nav_producer);
    }
}