package com.cesanelli.lajusta.ui;

import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.PorterDuff;
import android.util.Base64;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import androidx.recyclerview.widget.RecyclerView;

import com.cesanelli.lajusta.R;
import com.cesanelli.lajusta.io.models.Producer;

import java.util.List;

/**
 * {@link RecyclerView.Adapter} that can display a {@link Producer}.
 * TODO: Replace the implementation with code for your data type.
 */
public class ProducersRecyclerViewAdapter extends RecyclerView.Adapter<ProducersRecyclerViewAdapter.ViewHolder> {

    private final List<Producer> producers;
    private ProducersRecyclerViewAdapter.OnProducerListener onProducerListener;

    public ProducersRecyclerViewAdapter(List<Producer> producers, OnProducerListener onProducerListener) {
        this.producers = producers;
        this.onProducerListener = onProducerListener;
    }

    @Override
    public ViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        View view = LayoutInflater.from(parent.getContext())
                .inflate(R.layout.fragment_producers, parent, false);
        return new ViewHolder(view, onProducerListener);
    }

    @Override
    public void onBindViewHolder(final ViewHolder holder, int position) {
        holder.producer = producers.get(position);
        if (holder.producer.getImages().length > 0) {
            String cleanImage = holder.producer.getImages()[0].getValue().replace("data:image/png;base64,", "").replace("data:image/jpeg;base64,", "");
            byte[] decodedString = Base64.decode(cleanImage, Base64.DEFAULT);
            Bitmap decodedByte = BitmapFactory.decodeByteArray(decodedString, 0, decodedString.length);
            holder.producer_image.setImageBitmap(decodedByte);
        }else{
            holder.producer_image.setImageResource(R.drawable.ic_baseline_person_24);
            holder.producer_image.setColorFilter( 0xffcccccc, PorterDuff.Mode.MULTIPLY );
        }
        holder.producer_name.setText(holder.producer.getName());
    }

    @Override
    public int getItemCount() {
        return producers.size();
    }

    public interface OnProducerListener {
        void onProducerClick(Producer producer);
    }

    public class ViewHolder extends RecyclerView.ViewHolder {
        public final View mView;
        public final ImageView producer_image;
        public final TextView producer_name;
        public Producer producer;
        OnProducerListener onProducerListener;

        public ViewHolder(View view, OnProducerListener onProducerListener) {
            super(view);
            mView = view;
            producer_image = (ImageView) view.findViewById(R.id.producer_image);
            producer_name = (TextView) view.findViewById(R.id.producer_name);
            this.onProducerListener = onProducerListener;

            view.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    onProducerListener.onProducerClick(producer);
                }
            });
        }

        @Override
        public String toString() {
            return super.toString() + " '" + producer_name.getText() + "'";
        }
    }
}