package com.cesanelli.lajusta.ui;

import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.Spinner;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.fragment.app.Fragment;
import androidx.lifecycle.ViewModelProvider;
import androidx.navigation.Navigation;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.cesanelli.lajusta.R;
import com.cesanelli.lajusta.databinding.FragmentProductsListBinding;
import com.cesanelli.lajusta.io.models.Category;
import com.cesanelli.lajusta.io.models.Product;
import com.cesanelli.lajusta.ui.viewmodel.CartViewModel;
import com.cesanelli.lajusta.ui.viewmodel.ProductListViewModel;
import com.cesanelli.lajusta.ui.viewmodel.ProductViewModel;

import java.util.ArrayList;

public class ProductsFragment extends Fragment implements ProductsRecyclerViewAdapter.OnProductListener, AdapterView.OnItemSelectedListener {
    private ProductViewModel productViewModel;
    private ProductListViewModel productListViewModel;
    private CartViewModel cartViewModel;
    private FragmentProductsListBinding fragmentProductsListBinding;

    public ProductsFragment() {
    }

    public static ProductsFragment newInstance() {
        ProductsFragment fragment = new ProductsFragment();
        return fragment;
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        LayoutInflater layoutInflater = LayoutInflater.from(getContext());
        fragmentProductsListBinding = FragmentProductsListBinding.inflate(layoutInflater, container, false);
        return fragmentProductsListBinding.getRoot();
    }

    @Override
    public void onViewCreated(@NonNull View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);
        productViewModel = new ViewModelProvider(getActivity()).get(ProductViewModel.class);
        cartViewModel = new ViewModelProvider(getActivity()).get(CartViewModel.class);
        cartViewModel.getCart().observe(getViewLifecycleOwner(), cart -> {
            if (cart != null) {
                fragmentProductsListBinding.setCart(cart);
            }
        });
        productListViewModel = new ViewModelProvider(getActivity()).get(ProductListViewModel.class);
        productListViewModel.getProductList().observe(getViewLifecycleOwner(), list -> {
            if (list != null) {
                RecyclerView recyclerView = (RecyclerView) view.findViewById(R.id.listProducts);
                recyclerView.setLayoutManager(new LinearLayoutManager(getContext()));
                recyclerView.setAdapter(new ProductsRecyclerViewAdapter((ArrayList<Product>) list, this));
            }
        });
        productListViewModel.getCategories().observe(getViewLifecycleOwner(), categories -> {
            if (categories != null) {
                Spinner categoriesSpinner = (Spinner) view.findViewById(R.id.categories);
                ArrayAdapter adapter = new ArrayAdapter(getContext(), android.R.layout.simple_spinner_item, categories);
                adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
                categoriesSpinner.setAdapter(adapter);
                categoriesSpinner.setOnItemSelectedListener(this);
            }
        });
    }

    @Override
    public void onProductClick(Product product) {
        productViewModel.setProduct(product);
        Navigation.findNavController(getView()).navigate(R.id.nav_product);
    }

    @Override
    public void onProductAdd(Product product) {
        if(product.getStock()>0){
            cartViewModel.addProduct(product);
            Toast.makeText(getContext(), "Se agregó " + product.getTitle() + " al carrito.", Toast.LENGTH_SHORT).show();
        } else {
            Toast.makeText(getContext(), "Producto sin stock.", Toast.LENGTH_LONG).show();
        }
    }

    @Override
    public void onItemSelected(AdapterView<?> parent, View view, int position, long id) {
        productListViewModel.setCategory((Category) parent.getItemAtPosition(position));
    }

    @Override
    public void onNothingSelected(AdapterView<?> parent) {

    }
}