package com.cesanelli.lajusta.ui;

import android.os.Bundle;
import android.preference.PreferenceManager;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.fragment.app.Fragment;
import androidx.lifecycle.ViewModelProvider;
import androidx.navigation.Navigation;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.cesanelli.lajusta.R;
import com.cesanelli.lajusta.io.ApiAdapter;
import com.cesanelli.lajusta.io.models.ActiveNode;
import com.cesanelli.lajusta.io.models.Cart;
import com.cesanelli.lajusta.io.models.General;
import com.cesanelli.lajusta.ui.viewmodel.CartViewModel;
import com.cesanelli.lajusta.ui.viewmodel.UserViewModel;

import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;

public class PurchaseFragment extends Fragment implements PurchaseRecyclerViewAdapter.OnActiveNodeListener {
    private CartViewModel cartViewModel;
    private ActiveNode selectedNode;

    public PurchaseFragment() {
        // Required empty public constructor
    }

    public static PurchaseFragment newInstance(String param1, String param2) {
        PurchaseFragment fragment = new PurchaseFragment();
        return fragment;
    }

    @Override
    public void onViewCreated(@NonNull View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);
        Button btnComprar = view.findViewById(R.id.btnComprar);
        String jwt = PreferenceManager.getDefaultSharedPreferences(getContext()).getString("JWT", "");

        ApiAdapter.getApiService().getNodes().enqueue(new Callback<General>() {
            @Override
            public void onResponse(Call<General> call, Response<General> response) {
                try {
                    if (response.isSuccessful()) {
                        setActiveNodes(view, response.body());
                    }
                } catch (Exception ex) {
                    System.out.println(ex.toString());
                }
            }

            @Override
            public void onFailure(Call<General> call, Throwable t) {

            }
        });
        cartViewModel = new ViewModelProvider(getActivity()).get(CartViewModel.class);
        UserViewModel userViewModel = new ViewModelProvider(getActivity()).get(UserViewModel.class);
        cartViewModel.setUser(userViewModel.getToken().getValue().getUser());
        cartViewModel.getCart().observe(getActivity(), cart -> {
            if (cart != null) {
                TextView txtQuantity = view.findViewById(R.id.txtQuantity);
                txtQuantity.setText(String.valueOf(cart.getQuantity()));
                TextView txtTotal = view.findViewById(R.id.txtTotal);
                txtTotal.setText(String.valueOf(cart.getTotal()));
            }
            btnComprar.setEnabled(cart.getNode() != null && cart.getTotal() > 0);
        });

        btnComprar.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Cart cart = cartViewModel.getCart().getValue();
                ApiAdapter.getApiService().postCart(cart, "Bearer " + jwt).enqueue(new Callback<Cart>() {
                    @Override
                    public void onResponse(Call<Cart> call, Response<Cart> response) {
                        try {
                            if (response.isSuccessful()) {
                                Toast.makeText(getContext(), "Carrito grabado correctamente!", Toast.LENGTH_LONG).show();
                                Navigation.findNavController(v).navigate(R.id.nav_final);
                            } else {
                                System.out.println(response.toString());
                            }
                        } catch (Exception ex) {
                            System.out.println(ex.toString());
                        }
                    }

                    @Override
                    public void onFailure(Call<Cart> call, Throwable t) {
                        System.out.println(t.getMessage());
                    }
                });

            }
        });
    }

    private void setActiveNodes(View view, General general) {
        RecyclerView recyclerView = (RecyclerView) view.findViewById(R.id.nodeList);
        recyclerView.setLayoutManager(new LinearLayoutManager(view.getContext()));
        recyclerView.setAdapter(new PurchaseRecyclerViewAdapter(general, this));
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        // Inflate the layout for this fragment
        return inflater.inflate(R.layout.fragment_purchase, container, false);
    }

    @Override
    public void onSelectNode(ActiveNode node) {
        cartViewModel.setNode(node);
    }
}