package com.cesanelli.lajusta.ui;

import android.graphics.Color;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

import androidx.recyclerview.widget.RecyclerView;

import com.cesanelli.lajusta.R;
import com.cesanelli.lajusta.io.models.ActiveNode;
import com.cesanelli.lajusta.io.models.General;


public class PurchaseRecyclerViewAdapter extends RecyclerView.Adapter<PurchaseRecyclerViewAdapter.ViewHolder> {

    private final General general;
    private Integer selectedNode = -1;
    private OnActiveNodeListener onActiveNodeListener;


    public PurchaseRecyclerViewAdapter(General general, OnActiveNodeListener onActiveNodeListener) {
        this.general = general;
        this.onActiveNodeListener = onActiveNodeListener;
    }

    @Override
    public ViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        View view = LayoutInflater.from(parent.getContext())
                .inflate(R.layout.fragment_node, parent, false);
        return new PurchaseRecyclerViewAdapter.ViewHolder(view, onActiveNodeListener);
    }

    @Override
    public void onBindViewHolder(final ViewHolder holder, int position) {
        holder.node = general.getActiveNodes().get(position);
        holder.node_text.setText(holder.node.getNode().getName() + " - " + holder.node.getNode().getAddress().toString() + " - " + holder.node.getOpen());
        holder.position = position;
        holder.mView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                selectedNode=position;
                notifyDataSetChanged();
                onActiveNodeListener.onSelectNode(holder.node);
            }
        });
        if(selectedNode==position){
            holder.mView.setBackgroundColor(Color.parseColor("#FF88B24E"));
        }
        else
        {
            holder.mView.setBackgroundColor(Color.parseColor("#ffffff"));
        }
    }

    @Override
    public int getItemCount() {
        return general.getActiveNodes().size();
    }

    public interface OnActiveNodeListener {
        void onSelectNode(ActiveNode node);
    }

    public class ViewHolder extends RecyclerView.ViewHolder {
        public final View mView;
        public final TextView node_text;
        public ActiveNode node;
        public Integer position;
        OnActiveNodeListener onActiveNodeListener;

        public ViewHolder(View view, OnActiveNodeListener onActiveNodeListener) {
            super(view);
            mView = view;
            node_text = (TextView) view.findViewById(R.id.node_text);
        }
    }
}