package com.cesanelli.lajusta.ui;

import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.fragment.app.Fragment;
import androidx.lifecycle.ViewModelProvider;
import androidx.navigation.Navigation;

import com.cesanelli.lajusta.R;
import com.cesanelli.lajusta.io.ApiAdapter;
import com.cesanelli.lajusta.io.models.Signup;
import com.cesanelli.lajusta.io.models.Token;
import com.cesanelli.lajusta.io.models.User;
import com.cesanelli.lajusta.ui.viewmodel.UserViewModel;

import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;

public class RegisterFragment extends Fragment {
    private EditText user_firstname;
    private EditText user_lastname;
    private EditText user_email;
    private EditText user_phone;
    private EditText user_password;
    private EditText user_retry_password;

    public RegisterFragment() {
        // Required empty public constructor
    }

    public static RegisterFragment newInstance() {
        RegisterFragment fragment = new RegisterFragment();
        return fragment;
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        // Inflate the layout for this fragment
        return inflater.inflate(R.layout.fragment_register, container, false);
    }

    @Override
    public void onViewCreated(@NonNull View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);
        Button btnRegistrar = view.findViewById(R.id.btn_register);
        user_firstname = view.findViewById(R.id.user_firstname);
        user_lastname = view.findViewById(R.id.user_lastname);
        user_email = view.findViewById(R.id.user_email);
        user_phone = view.findViewById(R.id.user_phone);
        user_password = view.findViewById(R.id.user_password);
        user_retry_password = view.findViewById(R.id.user_retry_password);

        btnRegistrar.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (validateFirstname() && validateLastname() && validateEmail() && validatePhone() && validatePassword()) {

                    Signup user = new Signup(user_firstname.getText().toString().trim(),
                            user_lastname.getText().toString().trim(),
                            user_email.getText().toString().trim(),
                            user_phone.getText().toString().trim(),
                            user_password.getText().toString().trim());

                    ApiAdapter.getApiService().signup(user).enqueue(new Callback<User>() {
                        @Override
                        public void onResponse(Call<User> call, Response<User> response) {
                            try {
                                if (response.isSuccessful()) {
                                    Toast.makeText(getContext(), "Usuario registrado correctamente!", Toast.LENGTH_LONG).show();
                                    Navigation.findNavController(v).navigate(R.id.nav_products);
                                }
                            } catch (Exception ex) {
                                Toast.makeText(getContext(), ex.getMessage(), Toast.LENGTH_LONG).show();
                            }
                        }

                        @Override
                        public void onFailure(Call<User> call, Throwable t) {
                            Toast.makeText(getContext(), t.getMessage(), Toast.LENGTH_LONG).show();
                        }
                    });
                }
            }
        });
    }

    private boolean validateFirstname() {
        if (user_firstname.getText().toString().trim().length() < 3) {
            user_firstname.setError("El nombre debe tener más de 3 letras.");
            return false;
        }
        return true;
    }

    private boolean validateLastname() {
        if (user_lastname.getText().toString().trim().length() < 3) {
            user_lastname.setError("El apellido debe tener más de 3 letras.");
            return false;
        }
        return true;
    }

    private boolean validateEmail() {
        String email = user_email.getText().toString().trim();
        String emailPattern = "([a-zA-Z0-9_\\-\\.]+)@([a-zA-Z0-9_\\-\\.]+)\\.([a-zA-Z]{2,5})";
        if (!email.matches(emailPattern)) {
            user_email.setError("El email es inválido.");
            return false;
        }
        return true;
    }

    private boolean validatePhone() {
        String phone = user_phone.getText().toString().trim();
        String phonePattern = "^[+]?[0-9]{7,13}$";
        if (!phone.matches(phonePattern)) {
            user_phone.setError("El teléfono es inválido.");
            return false;
        }
        return true;
    }

    private boolean validatePassword() {
        String pass = user_password.getText().toString().trim();
        String pass_r = user_retry_password.getText().toString().trim();

        if (pass.length() < 3) {
            user_password.setError("El Password debe tener más de 3 letras.");
            return false;
        }

        if (!pass.equals(pass_r)) {
            user_retry_password.setError("Reiteración de password incorrecta.");
            return false;
        }
        return true;
    }
}