package com.cesanelli.lajusta.ui.viewmodel;

import androidx.lifecycle.LiveData;
import androidx.lifecycle.MutableLiveData;
import androidx.lifecycle.ViewModel;

import com.cesanelli.lajusta.io.models.ActiveNode;
import com.cesanelli.lajusta.io.models.Cart;
import com.cesanelli.lajusta.io.models.CartItem;
import com.cesanelli.lajusta.io.models.Product;
import com.cesanelli.lajusta.io.models.User;

import java.util.ArrayList;
import java.util.List;

public class CartViewModel extends ViewModel {
    final private MutableLiveData<Cart> cart = new MutableLiveData<Cart>();

    public CartViewModel() {
        cart.setValue(new Cart());
    }

    public LiveData<Cart> getCart() {
        return cart;
    }

    public void addProduct(Product product) {
        Boolean exists = false;
        Cart cart = this.cart.getValue();
        List<CartItem> items = cart.getCartProducts();
        for (CartItem cartItem : items) {
            if (cartItem.getProduct().getId() == product.getId()) {
                cartItem.setQuantity(cartItem.getQuantity() + 1);
                exists = true;
            }
        }
        if (!exists) {
            items.add(new CartItem(product, 1));
        }
        cart.setQuantity(cart.getQuantity() + 1);
        cart.setTotal(cart.getTotal() + product.getBuyPrice());
        this.cart.setValue(cart);
    }

    public void deleteProduct(Integer id) {
        CartItem cartItem = null;
        Cart cart = this.cart.getValue();
        List<CartItem> items = cart.getCartProducts();
        for (CartItem item : items) {
            if (item.getProduct().getId() == id) {
                cartItem = item;
            }
        }

        if (cartItem != null) {
            items.remove(cartItem);
        }
        cart.setQuantity(cart.getQuantity() - cartItem.getQuantity());
        cart.setTotal(cart.getTotal() - (cartItem.getQuantity() * cartItem.getProduct().getBuyPrice()));

        this.cart.setValue(this.cart.getValue());
    }

    public void addQuantity(Integer id) {
        CartItem cartItem = null;
        Cart cart = this.cart.getValue();
        List<CartItem> items = cart.getCartProducts();
        for (CartItem item : items) {
            if (item.getProduct().getId() == id) {
                item.setQuantity(item.getQuantity() + 1);
                cartItem = item;
            }
        }
        cart.setQuantity(cart.getQuantity() + 1);
        cart.setTotal(cart.getTotal() + cartItem.getProduct().getBuyPrice());
        this.cart.setValue(cart);
    }

    public void removeQuantity(Integer id) {
        CartItem cartItem = null;
        Cart cart = this.cart.getValue();
        List<CartItem> items = cart.getCartProducts();
        for (CartItem item : items) {
            if (item.getProduct().getId() == id) {
                item.setQuantity(item.getQuantity() - 1);
                cartItem = item;
            }
        }

        if (cartItem.getQuantity() == 0) {
            items.remove(cartItem);
        }

        cart.setQuantity(cart.getQuantity() - 1);
        cart.setTotal(cart.getTotal() - cartItem.getProduct().getBuyPrice());

        this.cart.setValue(cart);
    }

    public void restart(){
        Cart newCart = cart.getValue();
        Object[] products = newCart.getCartProducts().toArray();
        for (int i = 0; i < products.length; i++) {
            this.deleteProduct(((CartItem)products[i]).getProduct().getId());
        }
        this.setNode(null);
    }

    public void setNode (ActiveNode node){
        CartItem cartItem = null;
        Cart cart = this.cart.getValue();
        cart.setNode(node);
        this.cart.setValue(cart);
    }

    public void setUser (User user){
        CartItem cartItem = null;
        Cart cart = this.cart.getValue();
        cart.setUser(user);
        this.cart.setValue(cart);
    }
}
