package com.cesanelli.lajusta.ui.viewmodel;

import androidx.lifecycle.LiveData;
import androidx.lifecycle.MutableLiveData;
import androidx.lifecycle.ViewModel;

import com.cesanelli.lajusta.io.ApiAdapter;
import com.cesanelli.lajusta.io.models.News;
import com.cesanelli.lajusta.io.models.NewsItem;

import java.util.ArrayList;
import java.util.List;

import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;

public class NewsListViewModel extends ViewModel {
    private MutableLiveData<List<NewsItem>> news;

    public LiveData<List<NewsItem>> getNewsList() {
        if (news == null) {
            news = new MutableLiveData<List<NewsItem>>();
            loadNews();
        }
        return news;
    }

    public void setNewsList(List<NewsItem> news) {
        this.news.setValue(news);
    }

    private void loadNews() {
        Call<News> call = ApiAdapter.getApiService().getNews();
        call.enqueue(new Callback<News>() {

            @Override
            public void onResponse(Call<News> call, Response<News> response) {
                try {
                    if (response.isSuccessful()) {
                        setNewsList(response.body().getPage());
                    } else {
                        ArrayList<NewsItem> auxList = new ArrayList<NewsItem>();
                        for (int i = 1; i < 6; i++) {
                            auxList.add(new NewsItem("Título " + i, "Subtítulo " + i, "Este es un texto de prueba", null));
                        }
                        setNewsList(auxList);
                    }
                } catch (Exception ex) {
                    System.out.println(ex.toString());
                }
            }

            @Override
            public void onFailure(Call<News> call, Throwable t) {
                System.out.println(t.toString());
            }
        });
    }

}