package com.cesanelli.lajusta.ui.viewmodel;

import androidx.lifecycle.LiveData;
import androidx.lifecycle.MutableLiveData;
import androidx.lifecycle.ViewModel;

import com.cesanelli.lajusta.io.ApiAdapter;
import com.cesanelli.lajusta.io.models.Producer;

import java.util.ArrayList;
import java.util.List;

import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;

public class ProducerListViewModel extends ViewModel {
    private MutableLiveData<List<Producer>> producers;

    public LiveData<List<Producer>> getProducerList() {
        if (producers == null) {
            producers = new MutableLiveData<List<Producer>>();
            loadProducers();
        }

        return producers;
    }

    public void setProducerList(List<Producer> producers) {
        this.producers.setValue(producers);
    }

    private void loadProducers() {
        Call<ArrayList<Producer>> call = ApiAdapter.getApiService().getProducers();
        call.enqueue(new Callback<ArrayList<Producer>>() {

            @Override
            public void onResponse(Call<ArrayList<Producer>> call, Response<ArrayList<Producer>> response) {
                try {
                    if (response.isSuccessful()) {
                        setProducerList(response.body());
                    } else {
                        ArrayList<Producer> auxList = new ArrayList<Producer>();
                        for (int i = 1; i < 6; i++) {
                            auxList.add(new Producer(i, "Nombre " + i, "Apellido " + i, "email@email.com", null));
                        }
                        setProducerList(auxList);
                    }
                } catch (Exception ex) {
                    System.out.println(ex.toString());
                }
            }

            @Override
            public void onFailure(Call<ArrayList<Producer>> call, Throwable t) {
                System.out.println(t.toString());
            }
        });
    }

}