package com.cesanelli.lajusta.ui.viewmodel;

import androidx.lifecycle.LiveData;
import androidx.lifecycle.MutableLiveData;
import androidx.lifecycle.ViewModel;

import com.cesanelli.lajusta.io.ApiAdapter;
import com.cesanelli.lajusta.io.models.Category;
import com.cesanelli.lajusta.io.models.Product;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;

public class ProductListViewModel extends ViewModel {

    private MutableLiveData<List<Product>> products;
    private ArrayList<Product> productList;
    private MutableLiveData<List<Category>> categories;

    public LiveData<List<Product>> getProductList() {
        if (products == null) {
            products = new MutableLiveData<List<Product>>();
            loadProducts();
        }
        return products;
    }

    public void setProductList(List<Product> products) {
        this.productList = (ArrayList<Product>) products;

        Set<Category> categoriesList = new HashSet<Category>();
        for (Product p : products) {
            categoriesList.addAll(Arrays.asList(p.getCategories()));
        }

        ArrayList<Category> categories = new ArrayList<Category>();
        categories.add(new Category(0, "Todas"));
        categories.addAll(categoriesList);

        this.products.setValue(products);
        this.categories.setValue(categories);
    }

    public LiveData<List<Category>> getCategories() {
        if (categories == null) {
            categories = new MutableLiveData<List<Category>>();
        }
        return categories;
    }

    public void setCategory(Category category) {
        if (category == null || category.getId() == 0) {
            this.products.setValue(productList);
            return;
        }
        ArrayList<Product> filteredProducts = new ArrayList<Product>();
        for (Product p : productList) {
            for (Category c : p.getCategories()) {
                if (c.getId() == category.getId()) {
                    filteredProducts.add(p);
                    break;
                }
            }
        }
        this.products.setValue(filteredProducts);
    }

    private void loadProducts() {
        Call<ArrayList<Product>> call = ApiAdapter.getApiService().getProducts();
        call.enqueue(new Callback<ArrayList<Product>>() {

            @Override
            public void onResponse(Call<ArrayList<Product>> call, Response<ArrayList<Product>> response) {
                try {
                    if (response.isSuccessful()) {
                        setProductList(response.body());
                    }
                } catch (Exception ex) {
                    System.out.println(ex.toString());
                }
            }

            @Override
            public void onFailure(Call<ArrayList<Product>> call, Throwable t) {
                System.out.println(t.toString());
            }
        });
    }
}